=============
Release Notes
=============

0.1.4 (20 Mar 2014)
===================

* Data plane discovery (logs on to machines)
* Localhost discovery
* SSH module
* Templated output
* Bug fixes


0.1.3 (18 Feb 2014)
===================

* Bug fixes
* DNS added among other things


0.1.0 (28 Jan 2014)
===================

* Project setup
